Index: src/sas/guiframe/gui_manager.py
===================================================================
--- src/sas/guiframe/gui_manager.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/guiframe/gui_manager.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -69,5 +69,5 @@
     logging.info(sys.executable)
     logging.info(str(sys.argv))
-    from sas import sansview as sasview
+    from sas import sasview as sasview
     app_path = os.path.dirname(sasview.__file__)
     logging.info("Using application path: %s", app_path)
@@ -113,5 +113,5 @@
     if config is None:
         # Didn't find local config, load the default 
-import sas.guiframe.config as config
+        import sas.guiframe.config as config
         logging.info("using default local_config")        
     else:
@@ -2116,5 +2116,5 @@
         """
         if config._do_aboutbox:
-import sas.guiframe.aboutbox as AboutBox
+            import sas.guiframe.aboutbox as AboutBox
             dialog = AboutBox.DialogAbout(None, -1, "")
             dialog.ShowModal()   
Index: src/sas/perspectives/calculator/calculator.py
===================================================================
--- src/sas/perspectives/calculator/calculator.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/calculator.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -81,9 +81,9 @@
         slit_length_help = "Computes the slit length from the beam profile."
         resolution_help = "Approximately estimates the "
-        resolution_help += "resolution of Q in 2D based on the SANS "
+        resolution_help += "resolution of Q in 2D based on the SAS "
         resolution_help += "instrumental parameter values."
         mass_volume_help = "Based on the chemical formula, "
         mass_volume_help += "compute the mass density or the molar volume."
-        gensans_help = "Generic SANS"
+        gensas_help = "Generic SAS"
         pyconsole_help = "Python Console."
         imageviewer_help = "Load an image file and display the image."
@@ -98,8 +98,8 @@
                 ("Kiessig Thickness Calculator", 
                         kiessig_help, self.on_calculate_kiessig),
-                          ("SANS Resolution Estimator", 
+                          ("SAS Resolution Estimator", 
                         resolution_help, self.on_calculate_resoltuion),
                 ("Generic Scattering Calculator", 
-                        gensans_help, self.on_gen_model),
+                        gensas_help, self.on_gen_model),
                 ("Python Shell/Editor", pyconsole_help, self.on_python_console),
                 ("Image Viewer", imageviewer_help, self.on_image_viewer),]
Index: src/sas/perspectives/calculator/data_operator.py
===================================================================
--- src/sas/perspectives/calculator/data_operator.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/data_operator.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -600,5 +600,5 @@
         self.output.name = name
         self.output.run = "Data Operation"
-        self.output.instrument = "SansView"
+        self.output.instrument = "SasView"
         self.output.id = str(name) + str(time.time())
         data = {self.output.id :self.output}
Index: src/sas/perspectives/calculator/gen_scatter_panel.py
===================================================================
--- src/sas/perspectives/calculator/gen_scatter_panel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/gen_scatter_panel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -29,5 +29,5 @@
 from sas.guiframe.utils import format_number
 from sas.guiframe.events import StatusEvent  
-from sas.calculator import sans_gen 
+from sas.calculator import sas_gen 
 from sas.perspectives.calculator.calculator_widgets import OutputTextCtrl
 from sas.perspectives.calculator.calculator_widgets import InputTextCtrl
@@ -116,7 +116,7 @@
     """
     ## Internal nickname for the window, used by the AUI manager
-    window_name = "Generic SANS Calculator"
+    window_name = "Generic SAS Calculator"
     ## Name to appear on the window title bar
-    window_caption = "Generic SANS "
+    window_caption = "Generic SAS "
     ## Flag to tell the AUI manager to put this panel in the center pane
     CENTER_PANE = True
@@ -133,12 +133,12 @@
         self.reader = None
         self.ext = None
-        self.id = 'GenSANS'
+        self.id = 'GenSAS'
         self.file_name = ''
         self.time_text = None
         self.orient_combo = None
-        self.omfreader = sans_gen.OMFReader()
-        self.sldreader = sans_gen.SLDReader()
-        self.pdbreader = sans_gen.PDBReader()
-        self.model = sans_gen.GenSAS()
+        self.omfreader = sas_gen.OMFReader()
+        self.sldreader = sas_gen.SLDReader()
+        self.pdbreader = sas_gen.PDBReader()
+        self.model = sas_gen.GenSAS()
         self.param_dic = self.model.params
         self.parameters = []
@@ -451,6 +451,6 @@
         """
         sld_n_default = 6.97e-06
-        omfdata = sans_gen.OMFData()
-        omf2sld = sans_gen.OMF2SLD()
+        omfdata = sas_gen.OMFData()
+        omf2sld = sas_gen.OMF2SLD()
         omf2sld.set_data(omfdata, self.default_shape)
         self.sld_data = omf2sld.output
@@ -538,5 +538,5 @@
             if self.parent.parent is None:
                 return 
-            msg = "Generic SANS Calculator: %s" % (sys.exc_value)
+            msg = "Generic SAS Calculator: %s" % (sys.exc_value)
             wx.PostEvent(self.parent.parent,
                           StatusEvent(status=msg, type='stop'))
@@ -572,5 +572,5 @@
             self.is_avg = False
             if self.ext in self.omfreader.ext:
-                gen = sans_gen.OMF2SLD()
+                gen = sas_gen.OMF2SLD()
                 gen.set_data(data)
                 #omf_data = data
@@ -591,5 +591,5 @@
                 raise
             msg = "Loading Error: This file format is not supported "
-            msg += "for GenSANS." 
+            msg += "for GenSAS." 
             wx.PostEvent(self.parent.parent,
                           StatusEvent(status=msg, type='stop', info='Error'))
@@ -684,5 +684,5 @@
         graph_title = self._sld_plot_helper(ax, output, has_arrow)
         # Use y, z axes (in mpl 3d) as z, y axes 
-        # that consistent with our SANS detector coords.
+        # that consistent with our SAS detector coords.
         ax.set_xlabel('x ($\A%s$)'% output.pos_unit)
         ax.set_ylabel('z ($\A%s$)'% output.pos_unit)
@@ -1210,5 +1210,5 @@
         # Object that receive status event
         self.parent = parent
-        self.sld_data = sans_gen.MagSLD([0], [0], [0]) 
+        self.sld_data = sas_gen.MagSLD([0], [0], [0]) 
         self.sld_ctl = None
         self.default_shape = 'rectangular'
@@ -1277,5 +1277,5 @@
         """
         """
-        omfdata = sans_gen.OMFData()
+        omfdata = sas_gen.OMFData()
         sets = {}
         try:
@@ -1298,5 +1298,5 @@
                 exec "omfdata.%s = sets['%s']"% (key, key)            
 
-            omf2sld = sans_gen.OMF2SLD()
+            omf2sld = sas_gen.OMF2SLD()
             omf2sld.set_data(omfdata, self.default_shape)
             self.sld_data = omf2sld.output
@@ -1628,5 +1628,5 @@
         self.parent.set_main_panel_sld_data(self.sld_data)
         
-        reader = sans_gen.SLDReader() 
+        reader = sas_gen.SLDReader() 
         extension = '*.sld'
         path = None
@@ -1810,5 +1810,5 @@
         self.panel = SasGenPanel(parent=self)
         self.data = None
-        self.omfdata = sans_gen.OMFData()
+        self.omfdata = sas_gen.OMFData()
         self.sld_data = None
         self._default_save_location = os.getcwd() 
@@ -2117,8 +2117,8 @@
 
         media = calmedia.get_data_path(media='media')
-        path = os.path.join(media,"gen_sans_help.html") 
+        path = os.path.join(media,"gen_sas_help.html") 
         name = "Generic Scattering Calculator"
         frame = HelpWindow(self, -1, 
-                           title=' Help: GenSANS',  
+                           title=' Help: GenSAS',  
                            pageToOpen=path, size=(865, 450))   
         try: 
Index: src/sas/perspectives/calculator/help_panel.py
===================================================================
--- src/sas/perspectives/calculator/help_panel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/help_panel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -55,5 +55,5 @@
         if pageToOpen != None:
             path = os.path.dirname(pageToOpen)
-            self.path = os.path.join(path, "gen_sans_help.html")
+            self.path = os.path.join(path, "gen_sas_help.html")
         else:
             self.path = calculator.get_data_path(media='media')
@@ -80,5 +80,5 @@
             <li><a href ="resolution_calculator_help.html" 
             target ="showframe">Resolution Estimator</a><br></li>
-            <li><a href ="gen_sans_help.html" 
+            <li><a href ="gen_sas_help.html" 
             target ="showframe">Generic Scattering Calculator</a><br></li>
             <li><a href ="pycrust_help.html" 
Index: src/sas/perspectives/calculator/kiessig_calculator_panel.py
===================================================================
--- src/sas/perspectives/calculator/kiessig_calculator_panel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/kiessig_calculator_panel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -114,5 +114,5 @@
         hint_msg += "the thickness of a layer"
         hint_msg += " or the diameter of particles\n "
-        hint_msg += "from the Kiessig fringe width in SANS/NR data."
+        hint_msg += "from the Kiessig fringe width in SAS/NR data."
         hint_msg += ""
         self.hint_txt = wx.StaticText(self, -1, hint_msg)
Index: src/sas/perspectives/calculator/media/data_operator_help.html
===================================================================
--- src/sas/perspectives/calculator/media/data_operator_help.html	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/media/data_operator_help.html	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -23,5 +23,5 @@
 4) If the operation is successful, hit the Apply button to make the new data.
 Then the data name will be shown up in the data box in the data explorer.<br>
-Note: The errors and warnings will be displayed at the bottom of the SansView window. 
+Note: The errors and warnings will be displayed at the bottom of the SasView window. 
 </p> 
 <p>
Index: c/sas/perspectives/calculator/media/gen_sans_help.html
===================================================================
--- src/sas/perspectives/calculator/media/gen_sans_help.html	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ 	(revision )
@@ -1,147 +1,0 @@
-<body>
-<h4>Generic Scattering Calculator:</h4>
-Polarization and Magnetic Scattering
-<br>
-<br>
-<ul>
-<li><a href="#theory">Theory:</a></li>
-<li><a href="#gui">GUI</a></li>
-<li><a href="#pdb">PDB Data</a></li>
-</ul>
-<br>
-<br>
-<b>1. <a name="theory">Theory</a> </b>
-<br>
-In general, a particle with a volume V can be described by an ensemble containing N 
-3-dimensional rectangular pixels where each pixels are much smaller than V. 
-Assuming that
-all the pixel sizes are same, the elastic scattering intensity 
-by the particle 
-<p>
-<img src="gen_i.gif"/>
-</p>
-<br>
-where &#946;<sub>j</sub> and r<sub>j</sub> are the scattering 
-length density and the position 
-of the j'th pixel respectively. And the total volume
-<p>
-<img src="v_j.gif"/>
-</p>
-<br>
-for &#946;<sub>j</sub> &#8800; 0 where v<sub>j</sub> is the volume of the j'th pixel 
-(or the j'th natural atomic volume (= atomic mass/natural molar density/Avogadro number) 
- for the atomic structures). The total volume V can be corrected by users. 
-This correction is useful especially for an atomic structure (taken from a pdb file) to get the right 
-normalization. Note that the  &#946;<sub>j</sub> displayed in GUI may be incorrect but will not 
-affect the scattering computation if the correction of the total volume is made.
-<br>
-The scattering length density (SLD) of each pixel where the SLD is uniform, is a combination of the nuclear and magnetic SLDs 
-and depends on the spin states of the neutrons as follows:
-<br>
-<br>
-For magnetic scattering, only the magnetization component, <b>M</b><sub>perp</sub>, 
-perpendicular to the scattering vector <b>Q</b> contributes to the the magnetic 
-scattering length. (Figure below).
-<p>
-<img src="mag_vector.bmp"/>
-</p>
-<br>
-The magnetic scattering length density is then
-<p>
-<img src="dm_eq.gif"/>
-</p>
-<br>
-where &#947; = -1.913 the gyromagnetic ratio,  	&#956;<sub>B</sub> is the Bohr magneton, 
-r<sub>0</sub> is the classical radius of electron, 
-and <b>&#963;</b> is the Pauli spin.
-<br>
-For polarized neutron, the magnetic scattering is depending on the spin states.
-Let's consider that the incident neutrons are polarized parallel (+)/anti-parallel 
-(&#8211;) to the x' axis (See both Figures above).
-The possible out-coming states then are + and - states for both incident states.
-<br>
- - Non-spin-flips:  	(+ +) and  	(- -)
-<br>
- - Spin-flips:  	(+ -) and  	(- +)
-<br>
-<p>
-<img src="gen_mag_pic.bmp"/>
-</p>
-<br>
-<br>
-Now, let's assume that the angles of the <b>Q</b> vector and the spin-axis (x') from x-axis 
-are &#966; and  &#952;<sub>up</sub>, respectively (See Figure above).
-Then, depending upon the polarization (spin) state of neutrons, the scattering length
-densities , including the nuclear scattering length density (&#946; <sub>N</sub>) are given as, for non-spin-flips,
-<p>
-<img src="sld1.gif"/>
-</p>
-<br>
-<br>
-for spin-flips,
-<p>
-<img src="sld2.gif"/>
-</p>
-<br>
-<br>
-where
-<p>
-<img src="mxp.gif"/>
-</p>
-<p>
-<img src="myp.gif"/>
-</p>
-<p>
-<img src="mzp.gif"/>
-</p>
-<p>
-<img src="mqx.gif"/>
-</p>
-<p>
-<img src="mqy.gif"/>
-</p>
-<br>
-<br>
-Here, the M<sub>0x</sub>, M<sub>0y</sub> and M<sub>0z</sub> are the x, y and z 
-components of the magnetization vector given in the xyz lab frame.
-<br>
-<br>
-<b>2. <a name="gui">GUI</a> </b>
-<br>
-<p>
-<img src="gen_gui_help.bmp"/>
-</p>
-<br>
-<p>
-After the computation, the result will be listed in the 'Theory' box 
-in the data explorer panel on the main window.
-<br>
-The 'Up_frac_in' and 'Up_frac_out' are the ratio, (spin up) /(spin up + spin down) neutrons 
-before the sample and at the analyzer, respectively.
-</p>
-<br>
-*Note I: The values of 'Up_frac_in' and 'Up_frac_out' must be in the range between 0 and 1.
-For example, both values are 0.5 for unpolarized neutrons.
-<br>
-*Note II: This computation is totally based on the pixel (or atomic) data fixed
-in the xyz coordinates. Thus no angular orientational averaging is considered.
-<br>
-*Note III: For the nuclear scattering length density, only the real component is taken account.
-<br>
-<br>
-<b>3. <a name="pdb">PDB Data</a> </b>
-<br>
-This Generic scattering calculator also supports some pdb files without considering polarized/magnetic scattering
- so that the related parameters such as Up_*** will be ignored (see the Picture below). The calculation for fixed orientation uses (the first) Equation above resulting 
-in a 2D output, whileas the scattering calculation averaged over all the orientations uses the Debye equation providing a 1D output:
- <p>
-<img src="gen_debye_eq.gif"/>
-</p>
-<br>
-where v<sub>j</sub>&#946;<sub>j</sub> &#8801; b<sub>j</sub> is the scattering length of the j'th atom.
-The resultant outputs will be displayed in the DataExporer for further uses. 
-<br>
- <p>
-<img src="pdb_combo.jpg"/>
-</p>
-</body>
Index: src/sas/perspectives/calculator/media/gen_sas_help.html
===================================================================
--- src/sas/perspectives/calculator/media/gen_sas_help.html	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
+++ src/sas/perspectives/calculator/media/gen_sas_help.html	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -0,0 +1,147 @@
+<body>
+<h4>Generic Scattering Calculator:</h4>
+Polarization and Magnetic Scattering
+<br>
+<br>
+<ul>
+<li><a href="#theory">Theory:</a></li>
+<li><a href="#gui">GUI</a></li>
+<li><a href="#pdb">PDB Data</a></li>
+</ul>
+<br>
+<br>
+<b>1. <a name="theory">Theory</a> </b>
+<br>
+In general, a particle with a volume V can be described by an ensemble containing N 
+3-dimensional rectangular pixels where each pixels are much smaller than V. 
+Assuming that
+all the pixel sizes are same, the elastic scattering intensity 
+by the particle 
+<p>
+<img src="gen_i.gif"/>
+</p>
+<br>
+where &#946;<sub>j</sub> and r<sub>j</sub> are the scattering 
+length density and the position 
+of the j'th pixel respectively. And the total volume
+<p>
+<img src="v_j.gif"/>
+</p>
+<br>
+for &#946;<sub>j</sub> &#8800; 0 where v<sub>j</sub> is the volume of the j'th pixel 
+(or the j'th natural atomic volume (= atomic mass/natural molar density/Avogadro number) 
+ for the atomic structures). The total volume V can be corrected by users. 
+This correction is useful especially for an atomic structure (taken from a pdb file) to get the right 
+normalization. Note that the  &#946;<sub>j</sub> displayed in GUI may be incorrect but will not 
+affect the scattering computation if the correction of the total volume is made.
+<br>
+The scattering length density (SLD) of each pixel where the SLD is uniform, is a combination of the nuclear and magnetic SLDs 
+and depends on the spin states of the neutrons as follows:
+<br>
+<br>
+For magnetic scattering, only the magnetization component, <b>M</b><sub>perp</sub>, 
+perpendicular to the scattering vector <b>Q</b> contributes to the the magnetic 
+scattering length. (Figure below).
+<p>
+<img src="mag_vector.bmp"/>
+</p>
+<br>
+The magnetic scattering length density is then
+<p>
+<img src="dm_eq.gif"/>
+</p>
+<br>
+where &#947; = -1.913 the gyromagnetic ratio,  	&#956;<sub>B</sub> is the Bohr magneton, 
+r<sub>0</sub> is the classical radius of electron, 
+and <b>&#963;</b> is the Pauli spin.
+<br>
+For polarized neutron, the magnetic scattering is depending on the spin states.
+Let's consider that the incident neutrons are polarized parallel (+)/anti-parallel 
+(&#8211;) to the x' axis (See both Figures above).
+The possible out-coming states then are + and - states for both incident states.
+<br>
+ - Non-spin-flips:  	(+ +) and  	(- -)
+<br>
+ - Spin-flips:  	(+ -) and  	(- +)
+<br>
+<p>
+<img src="gen_mag_pic.bmp"/>
+</p>
+<br>
+<br>
+Now, let's assume that the angles of the <b>Q</b> vector and the spin-axis (x') from x-axis 
+are &#966; and  &#952;<sub>up</sub>, respectively (See Figure above).
+Then, depending upon the polarization (spin) state of neutrons, the scattering length
+densities , including the nuclear scattering length density (&#946; <sub>N</sub>) are given as, for non-spin-flips,
+<p>
+<img src="sld1.gif"/>
+</p>
+<br>
+<br>
+for spin-flips,
+<p>
+<img src="sld2.gif"/>
+</p>
+<br>
+<br>
+where
+<p>
+<img src="mxp.gif"/>
+</p>
+<p>
+<img src="myp.gif"/>
+</p>
+<p>
+<img src="mzp.gif"/>
+</p>
+<p>
+<img src="mqx.gif"/>
+</p>
+<p>
+<img src="mqy.gif"/>
+</p>
+<br>
+<br>
+Here, the M<sub>0x</sub>, M<sub>0y</sub> and M<sub>0z</sub> are the x, y and z 
+components of the magnetization vector given in the xyz lab frame.
+<br>
+<br>
+<b>2. <a name="gui">GUI</a> </b>
+<br>
+<p>
+<img src="gen_gui_help.bmp"/>
+</p>
+<br>
+<p>
+After the computation, the result will be listed in the 'Theory' box 
+in the data explorer panel on the main window.
+<br>
+The 'Up_frac_in' and 'Up_frac_out' are the ratio, (spin up) /(spin up + spin down) neutrons 
+before the sample and at the analyzer, respectively.
+</p>
+<br>
+*Note I: The values of 'Up_frac_in' and 'Up_frac_out' must be in the range between 0 and 1.
+For example, both values are 0.5 for unpolarized neutrons.
+<br>
+*Note II: This computation is totally based on the pixel (or atomic) data fixed
+in the xyz coordinates. Thus no angular orientational averaging is considered.
+<br>
+*Note III: For the nuclear scattering length density, only the real component is taken account.
+<br>
+<br>
+<b>3. <a name="pdb">PDB Data</a> </b>
+<br>
+This Generic scattering calculator also supports some pdb files without considering polarized/magnetic scattering
+ so that the related parameters such as Up_*** will be ignored (see the Picture below). The calculation for fixed orientation uses (the first) Equation above resulting 
+in a 2D output, whileas the scattering calculation averaged over all the orientations uses the Debye equation providing a 1D output:
+ <p>
+<img src="gen_debye_eq.gif"/>
+</p>
+<br>
+where v<sub>j</sub>&#946;<sub>j</sub> &#8801; b<sub>j</sub> is the scattering length of the j'th atom.
+The resultant outputs will be displayed in the DataExporer for further uses. 
+<br>
+ <p>
+<img src="pdb_combo.jpg"/>
+</p>
+</body>
Index: src/sas/perspectives/calculator/media/kiessig_calculator_help.html
===================================================================
--- src/sas/perspectives/calculator/media/kiessig_calculator_help.html	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/media/kiessig_calculator_help.html	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -11,5 +11,5 @@
 This tool is to approximately estimate the thickness of a layer
  or the diameter of particles from the Kiessig fringe in 
- SANS/NR data, and uses the Kiessig relation;
+ SAS/NR data, and uses the Kiessig relation;
  thickness = 2*Pi/fringe_width.
   
Index: src/sas/perspectives/calculator/media/resolution_calculator_help.html
===================================================================
--- src/sas/perspectives/calculator/media/resolution_calculator_help.html	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/media/resolution_calculator_help.html	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,5 +1,5 @@
 <html>
 <body>
-<h4>SANS Q Resolution Estimator</h4>
+<h4>SAS Q Resolution Estimator</h4>
 <ul>
 <li><a href="#Description">Description</a></li>
@@ -11,5 +11,5 @@
 <p>
 This tool is to approximately estimate the resolution of Q based on the
-SANS instrumental parameter values assuming that the detector is flat 
+SAS instrumental parameter values assuming that the detector is flat 
 and vertical to the incident beam direction.
 </p>
@@ -52,5 +52,5 @@
 the variance is slightly under estimated.</p>
 <p>7. The summary can be accessed by clicking the 'light-bulb' icon 
-at the bottom of the SansView main window.
+at the bottom of the SasView main window.
 </p>
 <p><img src="resolution_tutor.gif">
Index: src/sas/perspectives/calculator/media/slit_calculator_help.html
===================================================================
--- src/sas/perspectives/calculator/media/slit_calculator_help.html	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/media/slit_calculator_help.html	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -27,5 +27,5 @@
 
 <p>
-To see the file format, check the file, 'beam profile.DAT', in the 'test' folder of SansView. 
+To see the file format, check the file, 'beam profile.DAT', in the 'test' folder of SasView. 
 </p>
 </body>
Index: src/sas/perspectives/calculator/resolution_calculator_panel.py
===================================================================
--- src/sas/perspectives/calculator/resolution_calculator_panel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/calculator/resolution_calculator_panel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -58,5 +58,5 @@
     """
     ## Internal nickname for the window, used by the AUI manager
-    window_name = "SANS Resolution Estimator"
+    window_name = "SAS Resolution Estimator"
     ## Name to appear on the window title bar
     window_caption = ""
@@ -1397,5 +1397,5 @@
     """
     def __init__(self, parent = None, manager=None, 
-                 title = "SANS Resolution Estimator",
+                 title = "SAS Resolution Estimator",
                  size=(PANEL_WIDTH * 2, PANEL_HEIGHT), *args, **kwds):
         kwds['title'] = title
Index: src/sas/perspectives/fitting/basepage.py
===================================================================
--- src/sas/perspectives/fitting/basepage.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/basepage.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -2015,5 +2015,5 @@
                     temp_smear = self.current_smearer
             # compute weight for the current data
-            from sas import get_weight
+            from sas.perspectives.fitting.utils import get_weight
             flag = self.get_weight_flag()
             weight = get_weight(data=self.data, is2d=self._is_2D(), flag=flag)
@@ -3136,5 +3136,5 @@
         """
         from help_panel import  HelpWindow
-import sas.models as models
+        import sas.models as models
         
         # Get models help model_function path
@@ -3173,5 +3173,5 @@
         Get the string copies of the param names and values in the tap
         """
-        content = 'sansview_parameter_values:'
+        content = 'sasview_parameter_values:'
         # Do it if params exist
         if  self.parameters != []:
@@ -3402,5 +3402,5 @@
         # put the text into dictionary
         lines = text.split(':')
-        if lines[0] != 'sansview_parameter_values':
+        if lines[0] != 'sasview_parameter_values':
             self._copy_info(False)
             return False
Index: src/sas/perspectives/fitting/console.py
===================================================================
--- src/sas/perspectives/fitting/console.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/console.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -147,10 +147,10 @@
                 d_flag = (hasattr(self.result, "data") and \
                     self.result.data is not None and \
-                    hasattr(self.result.data, "sans_data") and 
-                    self.result.data.sans_data is not None)
+                    hasattr(self.result.data, "sas_data") and 
+                    self.result.data.sas_data is not None)
                 m_flag = (hasattr(self.result, "model") and \
                           self.result.model is not None)
                 if d_flag:
-                    data_name = self.result.data.sans_data.name
+                    data_name = self.result.data.sas_data.name
                 if m_flag:
                     model_name = str(self.result.model.name)
Index: src/sas/perspectives/fitting/fitpage.py
===================================================================
--- src/sas/perspectives/fitting/fitpage.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/fitpage.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -608,5 +608,5 @@
         model_disp = wx.StaticText(self, -1, 'Function')
         CHECK_STATE = self.cb1.GetValue()
-import sas.models.dispersion_models
+        import sas.models.dispersion_models
         self.polydisp = sas.models.dispersion_models.models
 
@@ -2175,5 +2175,5 @@
         """
         # compute weight for the current data
-        from sas import get_weight
+        from sas.perspectives.fitting.utils import get_weight
         flag_weight = self.get_weight_flag()
         if is_2D == None:
Index: src/sas/perspectives/fitting/fitting.py
===================================================================
--- src/sas/perspectives/fitting/fitting.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/fitting.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -33,12 +33,12 @@
 from sas.guiframe.data_processor import BatchCell
 from sas.fit.Fitting import Fit
-from sas import ConsoleUpdate
-from sas import FitProblemDictionary
-from sas import FitPanel
-from sas import ResultPanel, PlotResultEvent
-
-from sas import FitThread
-from sas import Reader
-from sas import Chi2UpdateEvent
+from sas.perspectives.fitting.console import ConsoleUpdate
+from sas.perspectives.fitting.fitproblem import FitProblemDictionary
+from sas.perspectives.fitting.fitpanel import FitPanel
+from sas.perspectives.fitting.resultpanel import ResultPanel, PlotResultEvent
+
+from sas.perspectives.fitting.fit_thread import FitThread
+from sas.perspectives.fitting.pagestate import Reader
+from sas.perspectives.fitting.fitpage import Chi2UpdateEvent
 from sas.perspectives.calculator.model_editor import TextDialog
 from sas.perspectives.calculator.model_editor import EditorWindow
Index: src/sas/perspectives/fitting/ftol_dialog.py
===================================================================
--- src/sas/perspectives/fitting/ftol_dialog.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/ftol_dialog.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -17,5 +17,5 @@
 # default ftol
 F_TOL = 1.49012e-08
-SANS_F_TOL = 5e-05
+SAS_F_TOL = 5e-05
 
 PANEL_WIDTH = 270
@@ -38,5 +38,5 @@
         vbox = wx.BoxSizer(wx.VERTICAL)
         title_text = wx.StaticText(self, id=wx.NewId(), label='FTol selection (Leastsq)')
-        self.default_bt = wx.RadioButton(self, -1, 'SansView Default (5e-05)', (15, 30), style=wx.RB_GROUP)
+        self.default_bt = wx.RadioButton(self, -1, 'SasView Default (5e-05)', (15, 30), style=wx.RB_GROUP)
         self.default_bt.SetValue(True)
         self.default_bt.Bind(wx.EVT_RADIOBUTTON, self.OnFtolSelection)
@@ -88,5 +88,5 @@
         """
         if self.default_bt.GetValue():
-            return SANS_F_TOL
+            return SAS_F_TOL
         elif self.sci_default_bt.GetValue():
             return F_TOL
@@ -102,3 +102,3 @@
             except:
                 return None
-        return SANS_F_TOL
+        return SAS_F_TOL
Index: src/sas/perspectives/fitting/media/category_manager_help.html
===================================================================
--- src/sas/perspectives/fitting/media/category_manager_help.html	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/media/category_manager_help.html	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -9,5 +9,5 @@
 <p>
 
-Our SANS models are, by default, classified into 5 categories; shapes, shape-independent, 
+Our SAS models are, by default, classified into 5 categories; shapes, shape-independent, 
 structure factor, and customized models, where these categories (except the customized models) can be reassigned, added, and removed using 'Category Manager'.
 Each models can also be enabled(shown)/disabled(hidden) from the category that they
Index: src/sas/perspectives/fitting/media/model_use_help.html
===================================================================
--- src/sas/perspectives/fitting/media/model_use_help.html	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/media/model_use_help.html	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -31,5 +31,5 @@
 	See 'Custom model editor' in the side menu on left.
 	Advanced users can write your own model and save it (in .py format) into <b>plugin_models</b> directory
-	in .sansview of your home directory (eg., username\.sansview>\plugin_models). You plugin
+	in .sasview of your home directory (eg., username\.sasview>\plugin_models). You plugin
 	model will be added into "<>Customized Models</>"  on the next model selection.
 </p>
Index: src/sas/perspectives/fitting/models.py
===================================================================
--- src/sas/perspectives/fitting/models.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/models.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -159,5 +159,5 @@
     dir = find_plugins_dir()
     if not os.path.isdir(dir):
-        msg = "SansView couldn't locate Model plugin folder."
+        msg = "SasView couldn't locate Model plugin folder."
         msg += """ "%s" does not exist""" % dir
         logging.warning(msg)
Index: src/sas/perspectives/fitting/pagestate.py
===================================================================
--- src/sas/perspectives/fitting/pagestate.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/pagestate.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -973,5 +973,5 @@
     ## Wildcards
     type = ["Fitting files (*.fitv)|*.fitv"
-            "SANSView file (*.svs)|*.svs"]
+            "SASView file (*.svs)|*.svs"]
     ## List of allowed extensions
     ext = ['.fitv', '.FITV', '.svs', 'SVS']
Index: src/sas/perspectives/fitting/plugin_models/polynomial5.py
===================================================================
--- src/sas/perspectives/fitting/plugin_models/polynomial5.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/plugin_models/polynomial5.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -11,5 +11,5 @@
 Please select the 'Compile' from the menubar after the modification and saving.
 Note that we recommend to save the file as a different file name.
-Otherwise, it could be removed in the future on re-installation of the SansView.
+Otherwise, it could be removed in the future on re-installation of the SasView.
 ## *****************************************************************************
 """
Index: src/sas/perspectives/fitting/plugin_models/sph_bessel_jn.py
===================================================================
--- src/sas/perspectives/fitting/plugin_models/sph_bessel_jn.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/plugin_models/sph_bessel_jn.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -11,5 +11,5 @@
 Please select the 'Compile' from the menubar after the modification and saving.
 Note that we recommend to save the file as a different file name.
-Otherwise, it could be removed in the future on re-installation of the SansView.
+Otherwise, it could be removed in the future on re-installation of the SasView.
 ## *****************************************************************************
 """
Index: src/sas/perspectives/fitting/plugin_models/sum_Ap1_1_Ap2.py
===================================================================
--- src/sas/perspectives/fitting/plugin_models/sum_Ap1_1_Ap2.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/plugin_models/sum_Ap1_1_Ap2.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -8,5 +8,5 @@
 Please select the 'Compile' from the menubar after the modification and saving.
 Note that we recommend to save the file as a different file name.
-Otherwise, it could be removed in the future on re-installation of the SansView.
+Otherwise, it could be removed in the future on re-installation of the SasView.
 ## *****************************************************************************
 """
Index: src/sas/perspectives/fitting/plugin_models/sum_p1_p2.py
===================================================================
--- src/sas/perspectives/fitting/plugin_models/sum_p1_p2.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/plugin_models/sum_p1_p2.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -8,5 +8,5 @@
 Please select the 'Compile' from the menubar after the modification and saving.
 Note that we recommend to save the file as a different file name.
-Otherwise, it could be removed in the future on re-installation of the SansView.
+Otherwise, it could be removed in the future on re-installation of the SasView.
 ## *****************************************************************************
 """
Index: src/sas/perspectives/fitting/plugin_models/testmodel.py
===================================================================
--- src/sas/perspectives/fitting/plugin_models/testmodel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/plugin_models/testmodel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -11,5 +11,5 @@
 Please select the 'Compile' from the menubar after the modification and saving.
 Note that we recommend to save the file as a different file name.
-Otherwise, it could be removed in the future on re-installation of the SansView.
+Otherwise, it could be removed in the future on re-installation of the SasView.
 ## *****************************************************************************
 """
Index: src/sas/perspectives/fitting/plugin_models/testmodel_2.py
===================================================================
--- src/sas/perspectives/fitting/plugin_models/testmodel_2.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/fitting/plugin_models/testmodel_2.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -11,5 +11,5 @@
 Please select the 'Compile' from the menubar after the modification and saving.
 Note that we recommend to save the file as a different file name.
-Otherwise, it could be removed in the future on re-installation of the SansView.
+Otherwise, it could be removed in the future on re-installation of the SasView.
 ## *****************************************************************************
 """
Index: src/sas/perspectives/invariant/help_panel.py
===================================================================
--- src/sas/perspectives/invariant/help_panel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/invariant/help_panel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -82,5 +82,5 @@
         self.rhelp = html.HtmlWindow(rpanel, -1, style=wx.NO_BORDER, 
                                      size=(500, -1))
-import sas.perspectives.invariant as invariant
+        import sas.perspectives.invariant as invariant
         path = invariant.get_data_path(media='media')
         self.path = os.path.join(path,"invariant_help.html")
Index: src/sas/perspectives/invariant/invariant.py
===================================================================
--- src/sas/perspectives/invariant/invariant.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/invariant/invariant.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -22,7 +22,7 @@
 from sas.guiframe.events import StatusEvent
 from sas.guiframe.gui_style import GUIFRAME_ID
-from sas import Reader as reader
+from sas.perspectives.invariant.invariant_state import Reader as reader
 from sas.dataloader.loader import Loader
-from sas import InvariantPanel
+from sas.perspectives.invariant.invariant_panel import InvariantPanel
 from sas.guiframe.plugin_base import PluginBase
 
Index: src/sas/perspectives/invariant/invariant_panel.py
===================================================================
--- src/sas/perspectives/invariant/invariant_panel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/invariant/invariant_panel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -14,9 +14,9 @@
 from sas.guiframe.events import StatusEvent
 from sas.guiframe.events import AppendBookmarkEvent
-from sas import InvariantDetailsPanel
-from sas import InvariantContainer
-from sas import OutputTextCtrl
-from sas import InvTextCtrl
-from sas import InvariantState as IState
+from sas.perspectives.invariant.invariant_details import InvariantDetailsPanel
+from sas.perspectives.invariant.invariant_details import InvariantContainer
+from sas.perspectives.invariant.invariant_widgets import OutputTextCtrl
+from sas.perspectives.invariant.invariant_widgets import InvTextCtrl
+from sas.perspectives.invariant.invariant_state import InvariantState as IState
 from sas.guiframe.panel_base import PanelBase
 # The minimum q-value to be used when extrapolating
@@ -766,5 +766,5 @@
         : param event: report button event
         """
-        from sas import ReportDialog
+        from sas.perspectives.invariant.report_dialog import ReportDialog
 
         self.state.set_report_string()
@@ -1914,5 +1914,5 @@
         self.loader = Loader()
         import invariant
-        path = "C:/ECLPS/workspace/trunk/sansdataloader/test/ascii_test_3.txt"
+        path = "C:/ECLPS/workspace/trunk/sasdataloader/test/ascii_test_3.txt"
         data = self.loader.load(path)
         self.panel = InvariantPanel(self)
Index: src/sas/perspectives/invariant/invariant_state.py
===================================================================
--- src/sas/perspectives/invariant/invariant_state.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/invariant/invariant_state.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -106,5 +106,5 @@
         self.wximbmp = None
         # report_html strings
-import sas.perspectives.invariant as invariant
+        import sas.perspectives.invariant as invariant
         path = invariant.get_data_path(media='media')
         path_report_html = os.path.join(path,"report_template.html")
@@ -643,5 +643,5 @@
     ## Wildcards
     type = ["Invariant file (*.inv)|*.inv",
-            "SANSView file (*.svs)|*.svs"]
+            "SASView file (*.svs)|*.svs"]
     ## List of allowed extensions
     ext = ['.inv', '.INV', '.svs', 'SVS']  
Index: src/sas/perspectives/pr/inversion_state.py
===================================================================
--- src/sas/perspectives/pr/inversion_state.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/perspectives/pr/inversion_state.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -359,5 +359,5 @@
     ## Wildcards
     type = ["P(r) files (*.prv)|*.prv",
-            "SANSView files (*.svs)|*.svs"]
+            "SASView files (*.svs)|*.svs"]
     ## List of allowed extensions
     ext = ['.prv', '.PRV', '.svs', '.SVS']  
Index: src/sas/plottools/fitDialog.py
===================================================================
--- src/sas/plottools/fitDialog.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/plottools/fitDialog.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -430,5 +430,5 @@
                     tempdy = numpy.asarray(tempdy)
                     tempdy[tempdy == 0] = 1
-                    chisqr, out, cov = fittings.sansfit(self.model,
+                    chisqr, out, cov = fittings.sasfit(self.model,
                                                         [self.cstA, self.cstB],
                                                         tempx, tempy,
@@ -439,5 +439,5 @@
                     tempdy = numpy.asarray(tempdy)
                     tempdy[tempdy == 0] = 1
-                    chisqr, out, cov = fittings.sansfit(self.model,
+                    chisqr, out, cov = fittings.sasfit(self.model,
                                                         [self.cstA, self.cstB],
                                                         tempx, tempy, tempdy,
Index: src/sas/plottools/fittings.py
===================================================================
--- src/sas/plottools/fittings.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/plottools/fittings.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -27,5 +27,5 @@
     
     
-def sansfit(model, pars, x, y, err_y , qmin=None, qmax=None):
+def sasfit(model, pars, x, y, err_y , qmin=None, qmax=None):
     """
     Fit function
@@ -90,5 +90,5 @@
     cstB = Parameter(line, 'B', event.cstB)
     y = line.run()
-    chisqr, out, cov = sansfit(line, [cstA, cstB], event.x, y, 0)
+    chisqr, out, cov = sasfit(line, [cstA, cstB], event.x, y, 0)
     # print "Output parameters:", out
     print "The right answer is [70.0, 1.0]"
Index: src/sas/pr/Doxyfile
===================================================================
--- src/sas/pr/Doxyfile	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/pr/Doxyfile	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -4,5 +4,5 @@
 # Project related configuration options
 #---------------------------------------------------------------------------
-PROJECT_NAME           = sanspr
+PROJECT_NAME           = saspr
 PROJECT_NUMBER         = 
 OUTPUT_DIRECTORY       = doc
Index: src/sas/pr/c_extensions/Cinvertor.c
===================================================================
--- src/sas/pr/c_extensions/Cinvertor.c	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/pr/c_extensions/Cinvertor.c	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1114,5 +1114,5 @@
 
     d = PyModule_GetDict(module);
-    CinvertorError = PyErr_NewException("sans.pr.invertor.Cinvertor.InvertorError", PyExc_RuntimeError, NULL);
+    CinvertorError = PyErr_NewException("sas.pr.invertor.Cinvertor.InvertorError", PyExc_RuntimeError, NULL);
     PyDict_SetItemString(d, "CinvertorError", CinvertorError);
 }
Index: src/sas/pr/release_notes.txt
===================================================================
--- src/sas/pr/release_notes.txt	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/pr/release_notes.txt	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -21,5 +21,5 @@
 
 	- Release date: 5/28/2008
-	- Provide python module sans.pr
+	- Provide python module sas.pr
 
 2- Downloading and Installing
@@ -29,5 +29,5 @@
 
 	2.2- Installing:
-		- Get the code from svn://danse.us/sans/releases/pr_inversion-0.1.0
+		- Get the code from svn://danse.us/sas/releases/pr_inversion-0.1.0
 		- The following modules are required:
 			* matplotlib
Index: src/sas/realspace/VolumeCanvas.py
===================================================================
--- src/sas/realspace/VolumeCanvas.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/realspace/VolumeCanvas.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -2,5 +2,5 @@
 """ Volume Canvas
 
-    Simulation canvas for real-space simulation of SANS scattering intensity.
+    Simulation canvas for real-space simulation of SAS scattering intensity.
     The user can create an arrangement of basic shapes and estimate I(q) and
     I(q_x, q_y). Error estimates on the simulation are also available. 
Index: src/sas/simulation/analmodelpy/analmodelpymodule/Make.mm
===================================================================
--- src/sas/simulation/analmodelpy/analmodelpymodule/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/analmodelpy/analmodelpymodule/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -12,5 +12,5 @@
 #
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 PACKAGE = analmodelpymodule
 MODULE = analmodelpy
Index: src/sas/simulation/analmodelpy/libanalmodelpy/Make.mm
===================================================================
--- src/sas/simulation/analmodelpy/libanalmodelpy/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/analmodelpy/libanalmodelpy/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -55,5 +55,5 @@
 EXPORT_HEADERS = \
     analytical_model.h  \
-    sans_model.h
+    sas_model.h
 
 EXPORT_LIBS = $(PROJ_SAR)
Index: src/sas/simulation/analmodelpy/libanalmodelpy/analytical_model.h
===================================================================
--- src/sas/simulation/analmodelpy/libanalmodelpy/analytical_model.h	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/analmodelpy/libanalmodelpy/analytical_model.h	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,12 +1,12 @@
-/** \file analytical_model.h class AnalyticalModel:SANSModel */
+/** \file analytical_model.h class AnalyticalModel:SASModel */
 
 #ifndef ANALYTICALMODEL_H
 #define ANALYTICALMODEL_H
 
-#include "sans_model.h"
+#include "sas_model.h"
 #include "geo_shape.h"
 #include "iq.h"
 
-class AnalyticalModel : public SANSModel{
+class AnalyticalModel : public SASModel{
 
  public:
Index: c/sas/simulation/analmodelpy/libanalmodelpy/sans_model.h
===================================================================
--- src/sas/simulation/analmodelpy/libanalmodelpy/sans_model.h	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ 	(revision )
@@ -1,15 +1,0 @@
-/** \file sans_model.h    class SANSModel virtual base class */
-
-#ifndef SANSMODEL_H
-#define SANSMODEL_H
-
-#include "iq.h"
-
-class SANSModel{
- public:
-
-  virtual void CalculateIQ(IQ *iq) = 0;
-
-};
-
-#endif
Index: src/sas/simulation/analmodelpy/libanalmodelpy/sas_model.h
===================================================================
--- src/sas/simulation/analmodelpy/libanalmodelpy/sas_model.h	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
+++ src/sas/simulation/analmodelpy/libanalmodelpy/sas_model.h	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -0,0 +1,15 @@
+/** \file sas_model.h    class SASModel virtual base class */
+
+#ifndef SASMODEL_H
+#define SASMODEL_H
+
+#include "iq.h"
+
+class SASModel{
+ public:
+
+  virtual void CalculateIQ(IQ *iq) = 0;
+
+};
+
+#endif
Index: src/sas/simulation/analmodelpy/tests/Make.mm
===================================================================
--- src/sas/simulation/analmodelpy/tests/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/analmodelpy/tests/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -16,5 +16,5 @@
 		     ../../geoshapespy/libgeoshapespy
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 PACKAGE = tests
 
Index: src/sas/simulation/analmodelpy/tests/testanal_model.py
===================================================================
--- src/sas/simulation/analmodelpy/tests/testanal_model.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/analmodelpy/tests/testanal_model.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -14,7 +14,7 @@
 if __name__ == "__main__":
 
-    from SANSsimulation import analmodelpy as analmodelpymodule
-    from SANSsimulation import iqPy
-    from SANSsimulation import geoshapespy
+    from SASsimulation import analmodelpy as analmodelpymodule
+    from SASsimulation import iqPy
+    from SASsimulation import geoshapespy
 
     print "copyright information:"
Index: src/sas/simulation/geoshapespy/geoshapespymodule/Make.mm
===================================================================
--- src/sas/simulation/geoshapespy/geoshapespymodule/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/geoshapespy/geoshapespymodule/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -12,5 +12,5 @@
 #
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 PACKAGE = geoshapespymodule
 MODULE = geoshapespy
Index: src/sas/simulation/geoshapespy/tests/testshapes.py
===================================================================
--- src/sas/simulation/geoshapespy/tests/testshapes.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/geoshapespy/tests/testshapes.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -14,5 +14,5 @@
 if __name__ == "__main__":
 
-    from SANSsimulation import geoshapespy
+    from SASsimulation import geoshapespy
 
     print
Index: src/sas/simulation/iqPy/Make.mm
===================================================================
--- src/sas/simulation/iqPy/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/iqPy/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -12,5 +12,5 @@
 #
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 
 # directory structure
Index: src/sas/simulation/iqPy/examples/Make.mm
===================================================================
--- src/sas/simulation/iqPy/examples/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/iqPy/examples/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -12,5 +12,5 @@
 #
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 PACKAGE = examples
 
Index: src/sas/simulation/iqPy/iqPy/Make.mm
===================================================================
--- src/sas/simulation/iqPy/iqPy/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/iqPy/iqPy/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -11,5 +11,5 @@
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 PACKAGE = iqPy
 
Index: src/sas/simulation/iqPy/iqPymodule/Make.mm
===================================================================
--- src/sas/simulation/iqPy/iqPymodule/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/iqPy/iqPymodule/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -12,5 +12,5 @@
 #
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 PACKAGE = iqPymodule
 MODULE = iqPy
Index: src/sas/simulation/iqPy/tests/testiq.py
===================================================================
--- src/sas/simulation/iqPy/tests/testiq.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/iqPy/tests/testiq.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -14,5 +14,5 @@
 if __name__ == "__main__":
 
-	from SANSsimulation import iqPy
+	from SASsimulation import iqPy
 	iqPy.new_iq(10,0.01,0.4)
 
Index: src/sas/simulation/pointsmodelpy/pointsmodelpymodule/Make.mm
===================================================================
--- src/sas/simulation/pointsmodelpy/pointsmodelpymodule/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/pointsmodelpymodule/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -12,5 +12,5 @@
 #
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 PACKAGE = pointsmodelpymodule
 MODULE = pointsmodelpy
Index: src/sas/simulation/pointsmodelpy/tests/testcomplexmodel.py
===================================================================
--- src/sas/simulation/pointsmodelpy/tests/testcomplexmodel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/tests/testcomplexmodel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,5 +1,5 @@
-from sansModeling.pointsmodelpy import pointsmodelpy
-from sansModeling.iqPy import iqPy
-from sansModeling.geoshapespy import geoshapespy
+from sasModeling.pointsmodelpy import pointsmodelpy
+from sasModeling.iqPy import iqPy
+from sasModeling.geoshapespy import geoshapespy
 
 #First testing: a normal case, a lores model holds a sphere
Index: src/sas/simulation/pointsmodelpy/tests/testnegativepr.py
===================================================================
--- src/sas/simulation/pointsmodelpy/tests/testnegativepr.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/tests/testnegativepr.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,6 +1,6 @@
 if __name__ == "__main__":
-  from sansModeling.pointsmodelpy import pointsmodelpy
-  from sansModeling.iqPy import iqPy
-  from sansModeling.geoshapespy import geoshapespy
+  from sasModeling.pointsmodelpy import pointsmodelpy
+  from sasModeling.iqPy import iqPy
+  from sasModeling.geoshapespy import geoshapespy
 
   a = geoshapespy.new_sphere(10)
Index: src/sas/simulation/setup.py
===================================================================
--- src/sas/simulation/setup.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/setup.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,4 +1,4 @@
 """
- Installation script for SANS models
+ Installation script for SAS models
 
   - To compile and install:
@@ -27,5 +27,5 @@
 
 # Top package name
-#pck_top = "sansModeling"
+#pck_top = "sasModeling"
 pck_top = "sas.simulation"
 pck_dir = os.path.join("src","sas", "simulation")
@@ -98,7 +98,7 @@
 
 setup(
-    name="sansrealspace_modeling",
+    name="sasrealspace_modeling",
     version = "0.2",
-    description = "Python module for SANS simulation",
+    description = "Python module for SAS simulation",
     author = "University of Tennessee",
     url = "http://danse.us/trac/sas",

Index: src/sas/pr/__init__.py
===================================================================
--- src/sas/pr/__init__.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/pr/__init__.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,6 +1,6 @@
 """
-    P(r) inversion for SANS
+    P(r) inversion for SAS
 """
 ## \mainpage P(r) inversion for SANS
 #
 # \section intro_sec Introduction
@@ -9,5 +9,5 @@
 # technique can be found elsewhere [1-5]. The module is useable as a 
 # standalone application but its functionality is meant to be presented 
 # to end-users through the user interface developed as part of the SANS 
 # flagship application. 
 #
@@ -1,6 +1,6 @@
 """
-## \mainpage P(r) inversion for SANS
+## \mainpage P(r) inversion for SAS
 #
 # \section intro_sec Introduction
@@ -9,5 +9,5 @@
 # technique can be found elsewhere [1-5]. The module is useable as a 
 # standalone application but its functionality is meant to be presented 
-# to end-users through the user interface developed as part of the SANS 
+# to end-users through the user interface developed as part of the SAS 
 # flagship application. 
 #
Index: src/sas/realspace/__init__.py
===================================================================
--- src/sas/realspace/__init__.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/realspace/__init__.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,9 +1,9 @@
 """
-    Real-Space Modeling for SANS
+    Real-Space Modeling for SAS
 """ 
 ## \mainpage Real-Space Modeling for SANS
 #
 # \section intro_sec Introduction
 # This module provides SANS scattering intensity simulation 
 # based on real-space modeling.
 #
@@ -1,9 +1,9 @@
 """ 
-## \mainpage Real-Space Modeling for SANS
+## \mainpage Real-Space Modeling for SAS
 #
 # \section intro_sec Introduction
@@ -1,9 +1,9 @@
 #
 # \section intro_sec Introduction
-# This module provides SANS scattering intensity simulation 
+# This module provides SAS scattering intensity simulation 
 # based on real-space modeling.
 #
Index: src/sas/simulation/pointsmodelpy/libpointsmodelpy/points_model.h
===================================================================
--- src/sas/simulation/pointsmodelpy/libpointsmodelpy/points_model.h	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/libpointsmodelpy/points_model.h	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,3 +1,3 @@
 /** \file points_model.h child class of SANSmodel*/
 
 #ifndef POINTSMODEL_H
@@ -9,9 +9,9 @@
 #include "Point3D.h"
 #include "iq.h"
-#include "sans_model.h"
+#include "sas_model.h"
 
 using namespace std;
 
-class PointsModel : public SANSModel{
+class PointsModel : public SASModel{
  public:
   PointsModel();
@@ -1,3 +1,3 @@
-/** \file points_model.h child class of SANSmodel*/
+/** \file points_model.h child class of SASmodel*/
 
 #ifndef POINTSMODEL_H
Index: src/sas/simulation/pointsmodelpy/tests/testlores.py
===================================================================
--- src/sas/simulation/pointsmodelpy/tests/testlores.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/tests/testlores.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,8 +1,8 @@
 if __name__ == "__main__":
 
-    from sansModeling.iqPy import iqPy
-    #from sansModeling.analmodelpy import analmodelpy as analmodelpymodule
-    from sansModeling.geoshapespy import geoshapespy
-    from sansModeling.pointsmodelpy import pointsmodelpy
+    from sasModeling.iqPy import iqPy
+    #from sasModeling.analmodelpy import analmodelpy as analmodelpymodule
+    from sasModeling.geoshapespy import geoshapespy
+    from sasModeling.pointsmodelpy import pointsmodelpy
 
 #    print "copyright information:"
Index: src/sas/simulation/pointsmodelpy/tests/testlores2d.py
===================================================================
--- src/sas/simulation/pointsmodelpy/tests/testlores2d.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/tests/testlores2d.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,6 +1,6 @@
 def test_lores2d(phi):
-  from sansModeling.pointsmodelpy import pointsmodelpy 
-  from sansModeling.iqPy import iqPy
-  from sansModeling.geoshapespy import geoshapespy
+  from sasModeling.pointsmodelpy import pointsmodelpy 
+  from sasModeling.iqPy import iqPy
+  from sasModeling.geoshapespy import geoshapespy
 
   #lores model is to hold several geometric objects
@@ -15,5 +15,5 @@
   pointsmodelpy.lores_add(lm,c,3.0)
 
   #retrieve the points from lores model for sans calculation
   vp = pointsmodelpy.new_point3dvec()
   pointsmodelpy.get_lorespoints(lm,vp)
@@ -30,7 +30,7 @@
   from Numeric import arange,zeros
   from enthought.util.numerix import Float,zeros
-  from sansModeling.file2array import readfile2array
-  from sansModeling.pointsmodelpy import pointsmodelpy
-  from sansModeling.geoshapespy import geoshapespy
+  from sasModeling.file2array import readfile2array
+  from sasModeling.pointsmodelpy import pointsmodelpy
+  from sasModeling.geoshapespy import geoshapespy
 
   lm = pointsmodelpy.new_loresmodel(0.1)
@@ -70,7 +70,7 @@
   from Numeric import arange,zeros
   from enthought.util.numerix import Float,zeros
-  from sansModeling.file2array import readfile2array
-  from sansModeling.pointsmodelpy import pointsmodelpy
-  from sansModeling.geoshapespy import geoshapespy
+  from sasModeling.file2array import readfile2array
+  from sasModeling.pointsmodelpy import pointsmodelpy
+  from sasModeling.geoshapespy import geoshapespy
 
   lm = pointsmodelpy.new_loresmodel(0.1)
@@ -15,5 +15,5 @@
   pointsmodelpy.lores_add(lm,c,3.0)
 
-  #retrieve the points from lores model for sans calculation
+  #retrieve the points from lores model for sas calculation
   vp = pointsmodelpy.new_point3dvec()
   pointsmodelpy.get_lorespoints(lm,vp)